### <img src="https://cdn2.hubspot.net/hubfs/100006/images/super_square_logo_3a.png" title="SeleniumBase" height="32"> SeleniumBase Help Documents

> **Table of Contents / Navigation:**
> - [**SeleniumBase Features List**](features_list.md)
> - [**How SeleniumBase Works**](how_it_works.md)
> - [**Webdriver Installation**](webdriver_installation.md)
> - [**Installing Python, Pip, & Git**](install_python_pip_git.md)
> - [**Python Virtual Env Tutorial**](virtualenv_instructions.md)
> - [**Verify Webdriver Installation**](verify_webdriver.md)
> - [**The Command Line Tutorial**](customizing_test_runs.md)
> - [**The Console Scripts Tutorial**](/seleniumbase/console_scripts/ReadMe.md)
> - [**SeleniumBase Method Summary**](method_summary.md)
> - [**MySQL Installation Overview**](mysql_installation.md)
> - [**Safari Driver Detailed Info**](using_safari_driver.md)
> - [**Seeing Hidden Files on macOS**](hidden_files_info.md)
> - [**SeleniumBase Case Studies**](happy_customers.md)
